@@ -23,7 +23,13 @@ from datetime import datetime
 from googleapiclient.discovery import build
 from googleapiclient.errors import HttpError
 
-from airflow.decorators import task
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
+
+if AIRFLOW_V_3_0_PLUS:
+    from airflow.sdk import task
+else:
+    # Airflow 2 path
+    from airflow.decorators import task  # type: ignore[attr-defined,no-redef]
 from airflow.exceptions import AirflowException
 from airflow.models.baseoperator import chain
 from airflow.models.dag import DAG
@@ -249,7 +255,6 @@ with DAG(
     # when "teardown" task with trigger rule is part of the DAG
     list(dag.tasks) >> watcher()
 
-
 from tests_common.test_utils.system_tests import get_test_run  # noqa: E402
 
 # Needed to run the example DAG with pytest (see: tests/system/README.md#run_via_pytest)
